# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_kubernetes_namespaced_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.apps import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_apps_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.autoscaling import v2_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_autoscaling_dot_v2__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.rbac import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_rbac_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.networking import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_networking_dot_v1__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8kubernetes/kubernetes_kubernetes_namespaced_bundle.proto\x12+sac_kubernetes.kubernetes_namespaced_bundle\x1a\x13shared/shared.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\x1a.kubernetes/kubernetes_io.k8s.api.apps.v1.proto\x1a\x35kubernetes/kubernetes_io.k8s.api.autoscaling.v2.proto\x1a.kubernetes/kubernetes_io.k8s.api.rbac.v1.proto\x1a\x34kubernetes/kubernetes_io.k8s.api.networking.v1.proto\"\xfa\x07\n\x15Kubernetes_Namespaced\x12\x35\n\x07\x62inding\x18\x01 \x03(\x0b\x32$.oak9.tython.k8s.api.core.v1.Binding\x12:\n\nconfig_map\x18\x02 \x03(\x0b\x32&.oak9.tython.k8s.api.core.v1.ConfigMap\x12-\n\x03pod\x18\x03 \x03(\x0b\x32 .oak9.tython.k8s.api.core.v1.Pod\x12\x44\n\x0fservice_account\x18\x04 \x03(\x0b\x32+.oak9.tython.k8s.api.core.v1.ServiceAccount\x12\x35\n\x07service\x18\x05 \x03(\x0b\x32$.oak9.tython.k8s.api.core.v1.Service\x12:\n\ndaemon_set\x18\x06 \x03(\x0b\x32&.oak9.tython.k8s.api.apps.v1.DaemonSet\x12;\n\ndeployment\x18\x07 \x03(\x0b\x32\'.oak9.tython.k8s.api.apps.v1.Deployment\x12<\n\x0breplica_set\x18\x08 \x03(\x0b\x32\'.oak9.tython.k8s.api.apps.v1.ReplicaSet\x12>\n\x0cstateful_set\x18\t \x03(\x0b\x32(.oak9.tython.k8s.api.apps.v1.StatefulSet\x12^\n\x19horizontal_pod_autoscaler\x18\n \x03(\x0b\x32;.oak9.tython.k8s.api.autoscaling.v2.HorizontalPodAutoscaler\x12>\n\x0cpod_template\x18\x0b \x03(\x0b\x32(.oak9.tython.k8s.api.core.v1.PodTemplate\x12\x33\n\x06secret\x18\x0c \x03(\x0b\x32#.oak9.tython.k8s.api.core.v1.Secret\x12>\n\x0crole_binding\x18\r \x03(\x0b\x32(.oak9.tython.k8s.api.rbac.v1.RoleBinding\x12/\n\x04role\x18\x0e \x03(\x0b\x32!.oak9.tython.k8s.api.rbac.v1.Role\x12;\n\x07ingress\x18\x0f \x03(\x0b\x32*.oak9.tython.k8s.api.networking.v1.Ingress\x12H\n\x0enetwork_policy\x18\x10 \x03(\x0b\x32\x30.oak9.tython.k8s.api.networking.v1.NetworkPolicyb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_kubernetes_namespaced_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KUBERNETES_NAMESPACED._serialized_start=380
  _KUBERNETES_NAMESPACED._serialized_end=1398
# @@protoc_insertion_point(module_scope)



"""Module providingFunction utilities for the runner."""
import importlib.util
from typing import List, Tuple, Optional
from core.types import Resource
from core.logger import _logger
from core.exception import GrpcPopulationException
from oak9.tython.models.shared.shared_pb2 import DesignGap, Violation, RunnerException
from google.protobuf.message import Message

log = _logger()


def module_from_file(module_name, file_path):
    spec = importlib.util.spec_from_file_location(module_name, file_path)
    module = importlib.util.module_from_spec(spec)
    spec.loader.exec_module(module)
    return module


def validation_results(results: List[Tuple[Resource, List[Violation], List[RunnerException]]]):
    grpc_design_gaps: list = []
    grpc_exceptions: list = []
    grpc_violation: list = []

    try:

        for resource, violations, exceptions, meta_info in results:
            for exception in exceptions:
                grpc_exception = RunnerException(
                    error_code=exception.error_code,
                    error_message=exception.error_message
                )

                grpc_exceptions.append(grpc_exception)

            for violation in violations:

                grpc_violation = Violation(
                    severity=violation.severity.name,
                    capability_id=violation.capability_id,
                    capability_name=violation.capability_name,

                    resource_id=violation.resource_id,
                    resource_type=violation.resource_type,
                    config_id=violation.config_id,
                    config_value=str(violation.config_value),
                    oak9_guidance="",
                    preffered_value=violation.preferred_value,
                    config_gap=violation.config_gap,
                    config_impact=violation.config_impact,
                    config_fix=violation.config_fix
                )

                if violation.capability_id in [existing_design_gap.capability_id for existing_design_gap in
                                               grpc_design_gaps]:
                    for existing_design_gap in grpc_design_gaps:
                        if existing_design_gap.capability_id == violation.capability_id:
                            existing_design_gap.violations.append(grpc_violation)
                else:

                    new_design_gap: DesignGap = DesignGap(
                        capability_id=violation.capability_id,
                        capability_name="",
                        source='Aws' if 'aws' in meta_info.resource_type.lower() else 'Azure',
                        resource_name=meta_info.resource_name,
                        resource_id=meta_info.resource_id,
                        resource_type=meta_info.resource_type,
                        # We may be able to get the below info from the blueprint once mapped
                        resource_gap="Critical",
                        resource_impact="Critical"
                    )

                    new_design_gap.violations.append(grpc_violation)
                    grpc_design_gaps.append(new_design_gap)

    except Exception as e:

        log.warning("Error", Message="Unable To Create gRPC Design Gap Response Due Exception", ErrorType=type(e),
                    Error=e, RequestId=meta_info.request_id, Caller=meta_info.caller)

        exception = GrpcPopulationException(meta_info, e)

        grpc_exception = RunnerException(
            error_code=exception.error_code,
            error_message=exception.error_message
        )

        grpc_exceptions.append(grpc_exception)

    return grpc_design_gaps, grpc_exceptions


def get_config_id_list(
        resource_to_flatten: Message,
        resource_name: str,
        config_name: str,
        sub_resource_id: Optional[int] = None) -> list[str]:
    """
    Passes The necessary information to the recursive function that will generate the list of config ids

    Args:
        resource_to_flatten: Resource that contains the configuration that is in violation
        resource_name: Name of the resource
        config_name: Name of the configuration
        sub_resource_id: ID of the subresource that contains config_name

    Returns:
        config_id_list: A list of strings is returned
    """

    config_name_list: list = []
    csp_list: list = ['azure', 'aws', 'gcp', 'kubernetes']

    def flatten(resource: Message, name: str):
        """
        Recursively traverses the resource dictionary to generate the unique_id for requested resource config.
        ! Throws a recursion error if the resource passed in contains circular dependencies in it proto definition !
        Args:
            resource: Object that contains resource configuration dictionary to be parsed
            name: Current name of resource
        Returns:
            config_id
        """
        resource_properties = [
            k for k in resource.DESCRIPTOR.fields_by_name.keys() if k != "resource_info"
        ]

        for resource_property in resource_properties:
            current_name = name + '.' + resource_property
            current_property = getattr(resource, resource_property)
            current_property_type = str(type(current_property))

            # if current_property is a list then iterate through it
            if 'RepeatedCompositeContainer' in current_property_type:
                i = 0
                for item in current_property:
                    flatten(item, current_name + '[' + str(i) + ']')
                    i = i + 1
            # if current_property is an object then flatten
            elif any(csp for csp in csp_list if csp in current_property_type):
                flatten(current_property, current_name)

            # found the config name of object we want
            if config_name in current_name and sub_resource_id is None:
                config_name_list.append(current_name)
            
            elif config_name in current_name and id(resource) == sub_resource_id:
                config_name_list.append(current_name)
                
            elif config_name in str(current_property) and id(resource) == sub_resource_id:
                if type(current_property) is str:
                    config_name_list.append(current_name + "." + current_property)

        return config_name_list

    return flatten(resource_to_flatten, resource_name)


def normalize_name_format(resource: Resource) -> str:
    """
    normalize_name_format returns a snake case version of the objects name
    Args:
        resource:  DESCRIPTOR Property from resource that contains the resource name.
    Returns:
        name: returns name of object in snake case
    """
    resource_name: str = resource.name[0]
    for counter, character in enumerate(resource.name):
        if character == "_" or counter == 0:
            continue
        elif character.isupper() and (resource_name[-1].islower() or resource_name[-1].isdigit()):
            resource_name += '_' + character
        else:
            resource_name += character

    return resource_name.lower()


def get_config_id(bundle: Message, config_name: str, sub_resource: Optional[Message] = None) -> str:

    if sub_resource is not None:
        sub_resource_id = id(sub_resource)
    else:
        sub_resource_id = None

    resource_name = normalize_name_format(bundle.DESCRIPTOR)
    config_id_list = get_config_id_list(bundle, resource_name, config_name, sub_resource_id)

    matches = []
    for config_id in config_id_list:
        if config_name == config_id.split('.')[-1]:
            matches.append(config_id)

    if not matches or len(matches) > 1:
        return ""

    return matches[0]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_accessanalyzer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61ws/aws_accessanalyzer.proto\x12\x1eoak9.tython.aws.accessanalyzer\x1a\x13shared/shared.proto\"\x96\x01\n\x0e\x41nalyzerFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x63ontains\x18\x02 \x03(\t\x12\n\n\x02\x65q\x18\x03 \x03(\t\x12\x0e\n\x06\x65xists\x18\x04 \x01(\x08\x12\x10\n\x08property\x18\x05 \x01(\t\x12\x0b\n\x03neq\x18\x06 \x03(\t\"\xa1\x01\n\x13\x41nalyzerArchiveRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12>\n\x06\x66ilter\x18\x02 \x03(\x0b\x32..oak9.tython.aws.accessanalyzer.AnalyzerFilter\x12\x11\n\trule_name\x18\x03 \x01(\t\"\xa3\x02\n\x08\x41nalyzer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\ranalyzer_name\x18\x02 \x01(\t\x12J\n\rarchive_rules\x18\x03 \x03(\x0b\x32\x33.oak9.tython.aws.accessanalyzer.AnalyzerArchiveRule\x12@\n\x04tags\x18\x04 \x03(\x0b\x32\x32.oak9.tython.aws.accessanalyzer.Analyzer.TagsEntry\x12\x0c\n\x04type\x18\x05 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"L\n\x0e\x41\x63\x63\x65ssAnalyzer\x12:\n\x08\x61nalyzer\x18\x01 \x03(\x0b\x32(.oak9.tython.aws.accessanalyzer.Analyzerb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_accessanalyzer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ANALYZER_TAGSENTRY._options = None
  _ANALYZER_TAGSENTRY._serialized_options = b'8\001'
  _ANALYZERFILTER._serialized_start=86
  _ANALYZERFILTER._serialized_end=236
  _ANALYZERARCHIVERULE._serialized_start=239
  _ANALYZERARCHIVERULE._serialized_end=400
  _ANALYZER._serialized_start=403
  _ANALYZER._serialized_end=694
  _ANALYZER_TAGSENTRY._serialized_start=651
  _ANALYZER_TAGSENTRY._serialized_end=694
  _ACCESSANALYZER._serialized_start=696
  _ACCESSANALYZER._serialized_end=772
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_kinesis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x15\x61ws/aws_kinesis.proto\x12\x17oak9.tython.aws.kinesis\x1a\x13shared/shared.proto\"z\n\x16StreamStreamEncryption\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x65ncryption_type\x18\x02 \x01(\t\x12\x0e\n\x06key_id\x18\x03 \x01(\t\"\xb6\x02\n\x06Stream\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x1e\n\x16retention_period_hours\x18\x03 \x01(\x05\x12\x13\n\x0bshard_count\x18\x04 \x01(\x05\x12J\n\x11stream_encryption\x18\x05 \x01(\x0b\x32/.oak9.tython.aws.kinesis.StreamStreamEncryption\x12\x37\n\x04tags\x18\x06 \x03(\x0b\x32).oak9.tython.aws.kinesis.Stream.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n\x07Kinesis\x12/\n\x06stream\x18\x01 \x01(\x0b\x32\x1f.oak9.tython.aws.kinesis.Stream\"t\n\x0eStreamConsumer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rconsumer_name\x18\x02 \x01(\t\x12\x12\n\nstream_arn\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_kinesis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STREAM_TAGSENTRY._options = None
  _STREAM_TAGSENTRY._serialized_options = b'8\001'
  _STREAMSTREAMENCRYPTION._serialized_start=71
  _STREAMSTREAMENCRYPTION._serialized_end=193
  _STREAM._serialized_start=196
  _STREAM._serialized_end=506
  _STREAM_TAGSENTRY._serialized_start=463
  _STREAM_TAGSENTRY._serialized_end=506
  _KINESIS._serialized_start=508
  _KINESIS._serialized_end=566
  _STREAMCONSUMER._serialized_start=568
  _STREAMCONSUMER._serialized_end=684
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_cloudfunctions.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgcp/gcp_cloudfunctions.proto\x12\x1eoak9.tython.gcp.cloudfunctions\x1a\x13shared/shared.proto\"B\n1CloudfunctionsFunctionXEventTriggerXFailurePolicy\x12\r\n\x05retry\x18\x01 \x01(\x08\"\xb6\x01\n#CloudfunctionsFunctionXEventTrigger\x12\x12\n\nevent_type\x18\x01 \x01(\t\x12\x10\n\x08resource\x18\x02 \x01(\t\x12i\n\x0e\x66\x61ilure_policy\x18\x03 \x01(\x0b\x32Q.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionXEventTriggerXFailurePolicy\"u\n1CloudfunctionsFunctionXSecretEnvironmentVariables\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0e\n\x06secret\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"N\n-CloudfunctionsFunctionXSecretVolumesXVersions\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\"\xbf\x01\n$CloudfunctionsFunctionXSecretVolumes\x12\x12\n\nmount_path\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0e\n\x06secret\x18\x03 \x01(\t\x12_\n\x08versions\x18\x04 \x03(\x0b\x32M.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionXSecretVolumesXVersions\"L\n\'CloudfunctionsFunctionXSourceRepository\x12\x14\n\x0c\x64\x65ployed_url\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\"_\n\x1f\x43loudfunctionsFunctionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0c\n\x04read\x18\x03 \x01(\t\x12\x0e\n\x06update\x18\x04 \x01(\t\"\xd2\x0c\n\x16\x43loudfunctionsFunction\x12\x1b\n\x13\x61vailable_memory_mb\x18\x01 \x01(\x01\x12z\n\x1b\x62uild_environment_variables\x18\x02 \x03(\x0b\x32U.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunction.BuildEnvironmentVariablesEntry\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x17\n\x0f\x64ocker_registry\x18\x04 \x01(\t\x12\x19\n\x11\x64ocker_repository\x18\x05 \x01(\t\x12\x13\n\x0b\x65ntry_point\x18\x06 \x01(\t\x12o\n\x15\x65nvironment_variables\x18\x07 \x03(\x0b\x32P.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunction.EnvironmentVariablesEntry\x12$\n\x1chttps_trigger_security_level\x18\x08 \x01(\t\x12\x19\n\x11https_trigger_url\x18\t \x01(\t\x12\n\n\x02id\x18\n \x01(\t\x12\x18\n\x10ingress_settings\x18\x0b \x01(\t\x12\x14\n\x0ckms_key_name\x18\x0c \x01(\t\x12R\n\x06labels\x18\r \x03(\x0b\x32\x42.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunction.LabelsEntry\x12\x15\n\rmax_instances\x18\x0e \x01(\x01\x12\x15\n\rmin_instances\x18\x0f \x01(\x01\x12\x0c\n\x04name\x18\x10 \x01(\t\x12\x0f\n\x07project\x18\x11 \x01(\t\x12\x0e\n\x06region\x18\x12 \x01(\t\x12\x0f\n\x07runtime\x18\x13 \x01(\t\x12\x1d\n\x15service_account_email\x18\x14 \x01(\t\x12\x1d\n\x15source_archive_bucket\x18\x15 \x01(\t\x12\x1d\n\x15source_archive_object\x18\x16 \x01(\t\x12\x0f\n\x07timeout\x18\x17 \x01(\x01\x12\x14\n\x0ctrigger_http\x18\x18 \x01(\x08\x12\x15\n\rvpc_connector\x18\x19 \x01(\t\x12%\n\x1dvpc_connector_egress_settings\x18\x1a \x01(\t\x12Z\n\revent_trigger\x18\x1b \x01(\x0b\x32\x43.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionXEventTrigger\x12w\n\x1csecret_environment_variables\x18\x1c \x03(\x0b\x32Q.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionXSecretEnvironmentVariables\x12\\\n\x0esecret_volumes\x18\x1d \x03(\x0b\x32\x44.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionXSecretVolumes\x12\x62\n\x11source_repository\x18\x1e \x01(\x0b\x32G.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionXSourceRepository\x12Q\n\x08timeouts\x18\x1f \x01(\x0b\x32?.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionXTimeouts\x12\x37\n\rresource_info\x18  \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a@\n\x1e\x42uildEnvironmentVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a;\n\x19\x45nvironmentVariablesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"d\n*CloudfunctionsFunctionIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xac\x02\n CloudfunctionsFunctionIamBinding\x12\x16\n\x0e\x63loud_function\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0f\n\x07members\x18\x04 \x03(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12]\n\tcondition\x18\x08 \x01(\x0b\x32J.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionIamBindingXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"c\n)CloudfunctionsFunctionIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xa9\x02\n\x1f\x43loudfunctionsFunctionIamMember\x12\x16\n\x0e\x63loud_function\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0e\n\x06member\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x0c\n\x04role\x18\x07 \x01(\t\x12\\\n\tcondition\x18\x08 \x01(\x0b\x32I.oak9.tython.gcp.cloudfunctions.CloudfunctionsFunctionIamMemberXCondition\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc2\x01\n\x1f\x43loudfunctionsFunctionIamPolicy\x12\x16\n\x0e\x63loud_function\x18\x01 \x01(\t\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x04 \x01(\t\x12\x0f\n\x07project\x18\x05 \x01(\t\x12\x0e\n\x06region\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_cloudfunctions_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOUDFUNCTIONSFUNCTION_BUILDENVIRONMENTVARIABLESENTRY._options = None
  _CLOUDFUNCTIONSFUNCTION_BUILDENVIRONMENTVARIABLESENTRY._serialized_options = b'8\001'
  _CLOUDFUNCTIONSFUNCTION_ENVIRONMENTVARIABLESENTRY._options = None
  _CLOUDFUNCTIONSFUNCTION_ENVIRONMENTVARIABLESENTRY._serialized_options = b'8\001'
  _CLOUDFUNCTIONSFUNCTION_LABELSENTRY._options = None
  _CLOUDFUNCTIONSFUNCTION_LABELSENTRY._serialized_options = b'8\001'
  _CLOUDFUNCTIONSFUNCTIONXEVENTTRIGGERXFAILUREPOLICY._serialized_start=85
  _CLOUDFUNCTIONSFUNCTIONXEVENTTRIGGERXFAILUREPOLICY._serialized_end=151
  _CLOUDFUNCTIONSFUNCTIONXEVENTTRIGGER._serialized_start=154
  _CLOUDFUNCTIONSFUNCTIONXEVENTTRIGGER._serialized_end=336
  _CLOUDFUNCTIONSFUNCTIONXSECRETENVIRONMENTVARIABLES._serialized_start=338
  _CLOUDFUNCTIONSFUNCTIONXSECRETENVIRONMENTVARIABLES._serialized_end=455
  _CLOUDFUNCTIONSFUNCTIONXSECRETVOLUMESXVERSIONS._serialized_start=457
  _CLOUDFUNCTIONSFUNCTIONXSECRETVOLUMESXVERSIONS._serialized_end=535
  _CLOUDFUNCTIONSFUNCTIONXSECRETVOLUMES._serialized_start=538
  _CLOUDFUNCTIONSFUNCTIONXSECRETVOLUMES._serialized_end=729
  _CLOUDFUNCTIONSFUNCTIONXSOURCEREPOSITORY._serialized_start=731
  _CLOUDFUNCTIONSFUNCTIONXSOURCEREPOSITORY._serialized_end=807
  _CLOUDFUNCTIONSFUNCTIONXTIMEOUTS._serialized_start=809
  _CLOUDFUNCTIONSFUNCTIONXTIMEOUTS._serialized_end=904
  _CLOUDFUNCTIONSFUNCTION._serialized_start=907
  _CLOUDFUNCTIONSFUNCTION._serialized_end=2525
  _CLOUDFUNCTIONSFUNCTION_BUILDENVIRONMENTVARIABLESENTRY._serialized_start=2353
  _CLOUDFUNCTIONSFUNCTION_BUILDENVIRONMENTVARIABLESENTRY._serialized_end=2417
  _CLOUDFUNCTIONSFUNCTION_ENVIRONMENTVARIABLESENTRY._serialized_start=2419
  _CLOUDFUNCTIONSFUNCTION_ENVIRONMENTVARIABLESENTRY._serialized_end=2478
  _CLOUDFUNCTIONSFUNCTION_LABELSENTRY._serialized_start=2480
  _CLOUDFUNCTIONSFUNCTION_LABELSENTRY._serialized_end=2525
  _CLOUDFUNCTIONSFUNCTIONIAMBINDINGXCONDITION._serialized_start=2527
  _CLOUDFUNCTIONSFUNCTIONIAMBINDINGXCONDITION._serialized_end=2627
  _CLOUDFUNCTIONSFUNCTIONIAMBINDING._serialized_start=2630
  _CLOUDFUNCTIONSFUNCTIONIAMBINDING._serialized_end=2930
  _CLOUDFUNCTIONSFUNCTIONIAMMEMBERXCONDITION._serialized_start=2932
  _CLOUDFUNCTIONSFUNCTIONIAMMEMBERXCONDITION._serialized_end=3031
  _CLOUDFUNCTIONSFUNCTIONIAMMEMBER._serialized_start=3034
  _CLOUDFUNCTIONSFUNCTIONIAMMEMBER._serialized_end=3331
  _CLOUDFUNCTIONSFUNCTIONIAMPOLICY._serialized_start=3334
  _CLOUDFUNCTIONSFUNCTIONIAMPOLICY._serialized_end=3528
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class NetworkAcl(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VPC_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    vpc_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vpc_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "tags", b"tags", "vpc_id", b"vpc_id"]) -> None: ...

global___NetworkAcl = NetworkAcl

@typing_extensions.final
class EC2_NetworkACL(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NETWORK_ACL_FIELD_NUMBER: builtins.int
    NETWORK_ACL_ENTRY_FIELD_NUMBER: builtins.int
    @property
    def network_acl(self) -> global___NetworkAcl: ...
    @property
    def network_acl_entry(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___NetworkAclEntry]: ...
    def __init__(
        self,
        *,
        network_acl: global___NetworkAcl | None = ...,
        network_acl_entry: collections.abc.Iterable[global___NetworkAclEntry] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["network_acl", b"network_acl"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["network_acl", b"network_acl", "network_acl_entry", b"network_acl_entry"]) -> None: ...

global___EC2_NetworkACL = EC2_NetworkACL

@typing_extensions.final
class NetworkAclEntryIcmp(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CODE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    code: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        code: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["code", b"code", "resource_info", b"resource_info"]) -> None: ...

global___NetworkAclEntryIcmp = NetworkAclEntryIcmp

@typing_extensions.final
class NetworkAclEntryPortRange(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    FROM_FIELD_NUMBER: builtins.int
    TO_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    to: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        to: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["from", b"from", "resource_info", b"resource_info", "to", b"to"]) -> None: ...

global___NetworkAclEntryPortRange = NetworkAclEntryPortRange

@typing_extensions.final
class NetworkAclEntry(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CIDR_BLOCK_FIELD_NUMBER: builtins.int
    EGRESS_FIELD_NUMBER: builtins.int
    ICMP_FIELD_NUMBER: builtins.int
    IPV6_CIDR_BLOCK_FIELD_NUMBER: builtins.int
    NETWORK_ACL_ID_FIELD_NUMBER: builtins.int
    PORT_RANGE_FIELD_NUMBER: builtins.int
    PROTOCOL_FIELD_NUMBER: builtins.int
    RULE_ACTION_FIELD_NUMBER: builtins.int
    RULE_NUMBER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cidr_block: builtins.str
    egress: builtins.bool
    @property
    def icmp(self) -> global___NetworkAclEntryIcmp: ...
    ipv6_cidr_block: builtins.str
    network_acl_id: builtins.str
    @property
    def port_range(self) -> global___NetworkAclEntryPortRange: ...
    protocol: builtins.int
    rule_action: builtins.str
    rule_number: builtins.int
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cidr_block: builtins.str = ...,
        egress: builtins.bool = ...,
        icmp: global___NetworkAclEntryIcmp | None = ...,
        ipv6_cidr_block: builtins.str = ...,
        network_acl_id: builtins.str = ...,
        port_range: global___NetworkAclEntryPortRange | None = ...,
        protocol: builtins.int = ...,
        rule_action: builtins.str = ...,
        rule_number: builtins.int = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["icmp", b"icmp", "port_range", b"port_range", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cidr_block", b"cidr_block", "egress", b"egress", "icmp", b"icmp", "ipv6_cidr_block", b"ipv6_cidr_block", "network_acl_id", b"network_acl_id", "port_range", b"port_range", "protocol", b"protocol", "resource_info", b"resource_info", "rule_action", b"rule_action", "rule_number", b"rule_number"]) -> None: ...

global___NetworkAclEntry = NetworkAclEntry



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_sql.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_sql.proto\x12\x13oak9.tython.gcp.sql\x1a\x13shared/shared.proto\"F\n\x14SqlDatabaseXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf7\x01\n\x0bSqlDatabase\x12\x0f\n\x07\x63harset\x18\x01 \x01(\t\x12\x11\n\tcollation\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08instance\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x11\n\tself_link\x18\x07 \x01(\t\x12;\n\x08timeouts\x18\x08 \x01(\x0b\x32).oak9.tython.gcp.sql.SqlDatabaseXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbf\x02\n(SqlDatabaseInstanceXReplicaConfiguration\x12\x16\n\x0e\x63\x61_certificate\x18\x01 \x01(\t\x12\x1a\n\x12\x63lient_certificate\x18\x02 \x01(\t\x12\x12\n\nclient_key\x18\x03 \x01(\t\x12\x1e\n\x16\x63onnect_retry_interval\x18\x04 \x01(\x01\x12\x16\n\x0e\x64ump_file_path\x18\x05 \x01(\t\x12\x17\n\x0f\x66\x61ilover_target\x18\x06 \x01(\x08\x12\x1f\n\x17master_heartbeat_period\x18\x07 \x01(\x01\x12\x10\n\x08password\x18\x08 \x01(\t\x12\x12\n\nssl_cipher\x18\t \x01(\t\x12\x10\n\x08username\x18\n \x01(\t\x12!\n\x19verify_server_certificate\x18\x0b \x01(\x08\"g\n(SqlDatabaseInstanceXRestoreBackupContext\x12\x15\n\rbackup_run_id\x18\x01 \x01(\x01\x12\x13\n\x0binstance_id\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\"D\n2SqlDatabaseInstanceXSettingsXActiveDirectoryConfig\x12\x0e\n\x06\x64omain\x18\x01 \x01(\t\"|\nHSqlDatabaseInstanceXSettingsXBackupConfigurationXBackupRetentionSettings\x12\x18\n\x10retained_backups\x18\x01 \x01(\x01\x12\x16\n\x0eretention_unit\x18\x02 \x01(\t\"\xd8\x02\n0SqlDatabaseInstanceXSettingsXBackupConfiguration\x12\x1a\n\x12\x62inary_log_enabled\x18\x01 \x01(\x08\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\x12\x10\n\x08location\x18\x03 \x01(\t\x12&\n\x1epoint_in_time_recovery_enabled\x18\x04 \x01(\x08\x12\x12\n\nstart_time\x18\x05 \x01(\t\x12&\n\x1etransaction_log_retention_days\x18\x06 \x01(\x01\x12\x80\x01\n\x19\x62\x61\x63kup_retention_settings\x18\x07 \x01(\x0b\x32].oak9.tython.gcp.sql.SqlDatabaseInstanceXSettingsXBackupConfigurationXBackupRetentionSettings\"I\n*SqlDatabaseInstanceXSettingsXDatabaseFlags\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t\"\xaa\x01\n+SqlDatabaseInstanceXSettingsXInsightsConfig\x12\x1e\n\x16query_insights_enabled\x18\x01 \x01(\x08\x12\x1b\n\x13query_string_length\x18\x02 \x01(\x01\x12\x1f\n\x17record_application_tags\x18\x03 \x01(\x08\x12\x1d\n\x15record_client_address\x18\x04 \x01(\x08\"w\n?SqlDatabaseInstanceXSettingsXIpConfigurationXAuthorizedNetworks\x12\x17\n\x0f\x65xpiration_time\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x81\x02\n,SqlDatabaseInstanceXSettingsXIpConfiguration\x12\x1a\n\x12\x61llocated_ip_range\x18\x01 \x01(\t\x12\x14\n\x0cipv4_enabled\x18\x02 \x01(\x08\x12\x17\n\x0fprivate_network\x18\x03 \x01(\t\x12\x13\n\x0brequire_ssl\x18\x04 \x01(\x08\x12q\n\x13\x61uthorized_networks\x18\x05 \x03(\x0b\x32T.oak9.tython.gcp.sql.SqlDatabaseInstanceXSettingsXIpConfigurationXAuthorizedNetworks\"w\n/SqlDatabaseInstanceXSettingsXLocationPreference\x12\x1e\n\x16\x66ollow_gae_application\x18\x01 \x01(\t\x12\x16\n\x0esecondary_zone\x18\x02 \x01(\t\x12\x0c\n\x04zone\x18\x03 \x01(\t\"a\n.SqlDatabaseInstanceXSettingsXMaintenanceWindow\x12\x0b\n\x03\x64\x61y\x18\x01 \x01(\x01\x12\x0c\n\x04hour\x18\x02 \x01(\x01\x12\x14\n\x0cupdate_track\x18\x03 \x01(\t\"x\n1SqlDatabaseInstanceXSettingsXSqlServerAuditConfig\x12\x0e\n\x06\x62ucket\x18\x01 \x01(\t\x12\x1a\n\x12retention_interval\x18\x02 \x01(\t\x12\x17\n\x0fupload_interval\x18\x03 \x01(\t\"\x92\t\n\x1cSqlDatabaseInstanceXSettings\x12\x19\n\x11\x61\x63tivation_policy\x18\x01 \x01(\t\x12\x19\n\x11\x61vailability_type\x18\x02 \x01(\t\x12\x11\n\tcollation\x18\x03 \x01(\t\x12\x17\n\x0f\x64isk_autoresize\x18\x04 \x01(\x08\x12\x1d\n\x15\x64isk_autoresize_limit\x18\x05 \x01(\x01\x12\x11\n\tdisk_size\x18\x06 \x01(\x01\x12\x11\n\tdisk_type\x18\x07 \x01(\t\x12\x14\n\x0cpricing_plan\x18\x08 \x01(\t\x12\x0c\n\x04tier\x18\t \x01(\t\x12V\n\x0buser_labels\x18\n \x03(\x0b\x32\x41.oak9.tython.gcp.sql.SqlDatabaseInstanceXSettings.UserLabelsEntry\x12\x0f\n\x07version\x18\x0b \x01(\x01\x12h\n\x17\x61\x63tive_directory_config\x18\x0c \x01(\x0b\x32G.oak9.tython.gcp.sql.SqlDatabaseInstanceXSettingsXActiveDirectoryConfig\x12\x63\n\x14\x62\x61\x63kup_configuration\x18\r \x01(\x0b\x32\x45.oak9.tython.gcp.sql.SqlDatabaseInstanceXSettingsXBackupConfiguration\x12W\n\x0e\x64\x61tabase_flags\x18\x0e \x03(\x0b\x32?.oak9.tython.gcp.sql.SqlDatabaseInstanceXSettingsXDatabaseFlags\x12Y\n\x0finsights_config\x18\x0f \x01(\x0b\x32@.oak9.tython.gcp.sql.SqlDatabaseInstanceXSettingsXInsightsConfig\x12[\n\x10ip_configuration\x18\x10 \x01(\x0b\x32\x41.oak9.tython.gcp.sql.SqlDatabaseInstanceXSettingsXIpConfiguration\x12\x61\n\x13location_preference\x18\x11 \x01(\x0b\x32\x44.oak9.tython.gcp.sql.SqlDatabaseInstanceXSettingsXLocationPreference\x12_\n\x12maintenance_window\x18\x12 \x01(\x0b\x32\x43.oak9.tython.gcp.sql.SqlDatabaseInstanceXSettingsXMaintenanceWindow\x12g\n\x17sql_server_audit_config\x18\x13 \x01(\x0b\x32\x46.oak9.tython.gcp.sql.SqlDatabaseInstanceXSettingsXSqlServerAuditConfig\x1a\x31\n\x0fUserLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"N\n\x1cSqlDatabaseInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x85\x08\n\x13SqlDatabaseInstance\x12\x17\n\x0f\x63onnection_name\x18\x01 \x01(\t\x12\x18\n\x10\x64\x61tabase_version\x18\x02 \x01(\t\x12\x1b\n\x13\x64\x65letion_protection\x18\x03 \x01(\x08\x12\x1b\n\x13\x65ncryption_key_name\x18\x04 \x01(\t\x12\x18\n\x10\x66irst_ip_address\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12K\n\nip_address\x18\x07 \x03(\x0b\x32\x37.oak9.tython.gcp.sql.SqlDatabaseInstance.IpAddressEntry\x12\x1c\n\x14master_instance_name\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x1a\n\x12private_ip_address\x18\n \x01(\t\x12\x0f\n\x07project\x18\x0b \x01(\t\x12\x19\n\x11public_ip_address\x18\x0c \x01(\t\x12\x0e\n\x06region\x18\r \x01(\t\x12\x15\n\rroot_password\x18\x0e \x01(\t\x12\x11\n\tself_link\x18\x0f \x01(\t\x12R\n\x0eserver_ca_cert\x18\x10 \x03(\x0b\x32:.oak9.tython.gcp.sql.SqlDatabaseInstance.ServerCaCertEntry\x12%\n\x1dservice_account_email_address\x18\x11 \x01(\t\x12\\\n\x15replica_configuration\x18\x12 \x01(\x0b\x32=.oak9.tython.gcp.sql.SqlDatabaseInstanceXReplicaConfiguration\x12]\n\x16restore_backup_context\x18\x13 \x01(\x0b\x32=.oak9.tython.gcp.sql.SqlDatabaseInstanceXRestoreBackupContext\x12\x43\n\x08settings\x18\x14 \x01(\x0b\x32\x31.oak9.tython.gcp.sql.SqlDatabaseInstanceXSettings\x12\x43\n\x08timeouts\x18\x15 \x01(\x0b\x32\x31.oak9.tython.gcp.sql.SqlDatabaseInstanceXTimeouts\x12\x37\n\rresource_info\x18\x16 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x30\n\x0eIpAddressEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a\x33\n\x11ServerCaCertEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"J\n(SqlSourceRepresentationInstanceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x9c\x02\n\x1fSqlSourceRepresentationInstance\x12\x18\n\x10\x64\x61tabase_version\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x01\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0e\n\x06region\x18\x07 \x01(\t\x12O\n\x08timeouts\x18\x08 \x01(\x0b\x32=.oak9.tython.gcp.sql.SqlSourceRepresentationInstanceXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"5\n\x13SqlSslCertXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xe4\x02\n\nSqlSslCert\x12\x0c\n\x04\x63\x65rt\x18\x01 \x01(\t\x12\x1a\n\x12\x63\x65rt_serial_number\x18\x02 \x01(\t\x12\x13\n\x0b\x63ommon_name\x18\x03 \x01(\t\x12\x13\n\x0b\x63reate_time\x18\x04 \x01(\t\x12\x17\n\x0f\x65xpiration_time\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x10\n\x08instance\x18\x07 \x01(\t\x12\x13\n\x0bprivate_key\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x16\n\x0eserver_ca_cert\x18\n \x01(\t\x12\x18\n\x10sha1_fingerprint\x18\x0b \x01(\t\x12:\n\x08timeouts\x18\x0c \x01(\x0b\x32(.oak9.tython.gcp.sql.SqlSslCertXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"F\n\x1cSqlUserXSqlServerUserDetails\x12\x10\n\x08\x64isabled\x18\x01 \x01(\x08\x12\x14\n\x0cserver_roles\x18\x02 \x03(\t\"B\n\x10SqlUserXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd3\x02\n\x07SqlUser\x12\x17\n\x0f\x64\x65letion_policy\x18\x01 \x01(\t\x12\x0c\n\x04host\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x10\n\x08instance\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x10\n\x08password\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x0c\n\x04type\x18\x08 \x01(\t\x12R\n\x17sql_server_user_details\x18\t \x01(\x0b\x32\x31.oak9.tython.gcp.sql.SqlUserXSqlServerUserDetails\x12\x37\n\x08timeouts\x18\n \x01(\x0b\x32%.oak9.tython.gcp.sql.SqlUserXTimeouts\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_sql_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SQLDATABASEINSTANCEXSETTINGS_USERLABELSENTRY._options = None
  _SQLDATABASEINSTANCEXSETTINGS_USERLABELSENTRY._serialized_options = b'8\001'
  _SQLDATABASEINSTANCE_IPADDRESSENTRY._options = None
  _SQLDATABASEINSTANCE_IPADDRESSENTRY._serialized_options = b'8\001'
  _SQLDATABASEINSTANCE_SERVERCACERTENTRY._options = None
  _SQLDATABASEINSTANCE_SERVERCACERTENTRY._serialized_options = b'8\001'
  _SQLDATABASEXTIMEOUTS._serialized_start=63
  _SQLDATABASEXTIMEOUTS._serialized_end=133
  _SQLDATABASE._serialized_start=136
  _SQLDATABASE._serialized_end=383
  _SQLDATABASEINSTANCEXREPLICACONFIGURATION._serialized_start=386
  _SQLDATABASEINSTANCEXREPLICACONFIGURATION._serialized_end=705
  _SQLDATABASEINSTANCEXRESTOREBACKUPCONTEXT._serialized_start=707
  _SQLDATABASEINSTANCEXRESTOREBACKUPCONTEXT._serialized_end=810
  _SQLDATABASEINSTANCEXSETTINGSXACTIVEDIRECTORYCONFIG._serialized_start=812
  _SQLDATABASEINSTANCEXSETTINGSXACTIVEDIRECTORYCONFIG._serialized_end=880
  _SQLDATABASEINSTANCEXSETTINGSXBACKUPCONFIGURATIONXBACKUPRETENTIONSETTINGS._serialized_start=882
  _SQLDATABASEINSTANCEXSETTINGSXBACKUPCONFIGURATIONXBACKUPRETENTIONSETTINGS._serialized_end=1006
  _SQLDATABASEINSTANCEXSETTINGSXBACKUPCONFIGURATION._serialized_start=1009
  _SQLDATABASEINSTANCEXSETTINGSXBACKUPCONFIGURATION._serialized_end=1353
  _SQLDATABASEINSTANCEXSETTINGSXDATABASEFLAGS._serialized_start=1355
  _SQLDATABASEINSTANCEXSETTINGSXDATABASEFLAGS._serialized_end=1428
  _SQLDATABASEINSTANCEXSETTINGSXINSIGHTSCONFIG._serialized_start=1431
  _SQLDATABASEINSTANCEXSETTINGSXINSIGHTSCONFIG._serialized_end=1601
  _SQLDATABASEINSTANCEXSETTINGSXIPCONFIGURATIONXAUTHORIZEDNETWORKS._serialized_start=1603
  _SQLDATABASEINSTANCEXSETTINGSXIPCONFIGURATIONXAUTHORIZEDNETWORKS._serialized_end=1722
  _SQLDATABASEINSTANCEXSETTINGSXIPCONFIGURATION._serialized_start=1725
  _SQLDATABASEINSTANCEXSETTINGSXIPCONFIGURATION._serialized_end=1982
  _SQLDATABASEINSTANCEXSETTINGSXLOCATIONPREFERENCE._serialized_start=1984
  _SQLDATABASEINSTANCEXSETTINGSXLOCATIONPREFERENCE._serialized_end=2103
  _SQLDATABASEINSTANCEXSETTINGSXMAINTENANCEWINDOW._serialized_start=2105
  _SQLDATABASEINSTANCEXSETTINGSXMAINTENANCEWINDOW._serialized_end=2202
  _SQLDATABASEINSTANCEXSETTINGSXSQLSERVERAUDITCONFIG._serialized_start=2204
  _SQLDATABASEINSTANCEXSETTINGSXSQLSERVERAUDITCONFIG._serialized_end=2324
  _SQLDATABASEINSTANCEXSETTINGS._serialized_start=2327
  _SQLDATABASEINSTANCEXSETTINGS._serialized_end=3497
  _SQLDATABASEINSTANCEXSETTINGS_USERLABELSENTRY._serialized_start=3448
  _SQLDATABASEINSTANCEXSETTINGS_USERLABELSENTRY._serialized_end=3497
  _SQLDATABASEINSTANCEXTIMEOUTS._serialized_start=3499
  _SQLDATABASEINSTANCEXTIMEOUTS._serialized_end=3577
  _SQLDATABASEINSTANCE._serialized_start=3580
  _SQLDATABASEINSTANCE._serialized_end=4609
  _SQLDATABASEINSTANCE_IPADDRESSENTRY._serialized_start=4508
  _SQLDATABASEINSTANCE_IPADDRESSENTRY._serialized_end=4556
  _SQLDATABASEINSTANCE_SERVERCACERTENTRY._serialized_start=4558
  _SQLDATABASEINSTANCE_SERVERCACERTENTRY._serialized_end=4609
  _SQLSOURCEREPRESENTATIONINSTANCEXTIMEOUTS._serialized_start=4611
  _SQLSOURCEREPRESENTATIONINSTANCEXTIMEOUTS._serialized_end=4685
  _SQLSOURCEREPRESENTATIONINSTANCE._serialized_start=4688
  _SQLSOURCEREPRESENTATIONINSTANCE._serialized_end=4972
  _SQLSSLCERTXTIMEOUTS._serialized_start=4974
  _SQLSSLCERTXTIMEOUTS._serialized_end=5027
  _SQLSSLCERT._serialized_start=5030
  _SQLSSLCERT._serialized_end=5386
  _SQLUSERXSQLSERVERUSERDETAILS._serialized_start=5388
  _SQLUSERXSQLSERVERUSERDETAILS._serialized_end=5458
  _SQLUSERXTIMEOUTS._serialized_start=5460
  _SQLUSERXTIMEOUTS._serialized_end=5526
  _SQLUSER._serialized_start=5529
  _SQLUSER._serialized_end=5868
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ec2_dhcpoptions.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61ws/aws_ec2_dhcpoptions.proto\x12\x1foak9.tython.aws.ec2_dhcpoptions\x1a\x13shared/shared.proto\"\xb9\x02\n\x0b\x44HCPOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64omain_name\x18\x02 \x01(\t\x12\x1b\n\x13\x64omain_name_servers\x18\x03 \x03(\t\x12\x1c\n\x14netbios_name_servers\x18\x04 \x03(\t\x12\x19\n\x11netbios_node_type\x18\x05 \x01(\x05\x12\x13\n\x0bntp_servers\x18\x06 \x03(\t\x12\x44\n\x04tags\x18\x07 \x03(\x0b\x32\x36.oak9.tython.aws.ec2_dhcpoptions.DHCPOptions.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"U\n\x0f\x45\x43\x32_DHCPOptions\x12\x42\n\x0c\x64hcp_options\x18\x01 \x01(\x0b\x32,.oak9.tython.aws.ec2_dhcpoptions.DHCPOptionsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ec2_dhcpoptions_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DHCPOPTIONS_TAGSENTRY._options = None
  _DHCPOPTIONS_TAGSENTRY._serialized_options = b'8\001'
  _DHCPOPTIONS._serialized_start=88
  _DHCPOPTIONS._serialized_end=401
  _DHCPOPTIONS_TAGSENTRY._serialized_start=358
  _DHCPOPTIONS_TAGSENTRY._serialized_end=401
  _EC2_DHCPOPTIONS._serialized_start=403
  _EC2_DHCPOPTIONS._serialized_end=488
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Ledger(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    PERMISSIONS_MODE_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    permissions_mode: builtins.str
    deletion_protection: builtins.bool
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        permissions_mode: builtins.str = ...,
        deletion_protection: builtins.bool = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["deletion_protection", b"deletion_protection", "name", b"name", "permissions_mode", b"permissions_mode", "resource_info", b"resource_info", "tags", b"tags"]) -> None: ...

global___Ledger = Ledger

@typing_extensions.final
class QLDB(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEDGER_FIELD_NUMBER: builtins.int
    STREAM_FIELD_NUMBER: builtins.int
    @property
    def ledger(self) -> global___Ledger: ...
    @property
    def stream(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Stream]: ...
    def __init__(
        self,
        *,
        ledger: global___Ledger | None = ...,
        stream: collections.abc.Iterable[global___Stream] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ledger", b"ledger"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ledger", b"ledger", "stream", b"stream"]) -> None: ...

global___QLDB = QLDB

@typing_extensions.final
class StreamKinesisConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    STREAM_ARN_FIELD_NUMBER: builtins.int
    AGGREGATION_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    stream_arn: builtins.str
    aggregation_enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        stream_arn: builtins.str = ...,
        aggregation_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["aggregation_enabled", b"aggregation_enabled", "resource_info", b"resource_info", "stream_arn", b"stream_arn"]) -> None: ...

global___StreamKinesisConfiguration = StreamKinesisConfiguration

@typing_extensions.final
class Stream(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    LEDGER_NAME_FIELD_NUMBER: builtins.int
    STREAM_NAME_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    INCLUSIVE_START_TIME_FIELD_NUMBER: builtins.int
    EXCLUSIVE_END_TIME_FIELD_NUMBER: builtins.int
    KINESIS_CONFIGURATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    ledger_name: builtins.str
    stream_name: builtins.str
    role_arn: builtins.str
    inclusive_start_time: builtins.str
    exclusive_end_time: builtins.str
    @property
    def kinesis_configuration(self) -> global___StreamKinesisConfiguration: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        ledger_name: builtins.str = ...,
        stream_name: builtins.str = ...,
        role_arn: builtins.str = ...,
        inclusive_start_time: builtins.str = ...,
        exclusive_end_time: builtins.str = ...,
        kinesis_configuration: global___StreamKinesisConfiguration | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kinesis_configuration", b"kinesis_configuration", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["exclusive_end_time", b"exclusive_end_time", "inclusive_start_time", b"inclusive_start_time", "kinesis_configuration", b"kinesis_configuration", "ledger_name", b"ledger_name", "resource_info", b"resource_info", "role_arn", b"role_arn", "stream_name", b"stream_name", "tags", b"tags"]) -> None: ...

global___Stream = Stream



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_pubsub.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14gcp/gcp_pubsub.proto\x12\x16oak9.tython.gcp.pubsub\x1a\x13shared/shared.proto\"P\n\x1ePubsubLiteReservationXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf2\x01\n\x15PubsubLiteReservation\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x0e\n\x06region\x18\x04 \x01(\t\x12\x1b\n\x13throughput_capacity\x18\x05 \x01(\x01\x12H\n\x08timeouts\x18\x06 \x01(\x0b\x32\x36.oak9.tython.gcp.pubsub.PubsubLiteReservationXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"E\n%PubsubLiteSubscriptionXDeliveryConfig\x12\x1c\n\x14\x64\x65livery_requirement\x18\x01 \x01(\t\"Q\n\x1fPubsubLiteSubscriptionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xcc\x02\n\x16PubsubLiteSubscription\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x0e\n\x06region\x18\x04 \x01(\t\x12\r\n\x05topic\x18\x05 \x01(\t\x12\x0c\n\x04zone\x18\x06 \x01(\t\x12V\n\x0f\x64\x65livery_config\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.pubsub.PubsubLiteSubscriptionXDeliveryConfig\x12I\n\x08timeouts\x18\x08 \x01(\x0b\x32\x37.oak9.tython.gcp.pubsub.PubsubLiteSubscriptionXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"f\n(PubsubLiteTopicXPartitionConfigXCapacity\x12\x1b\n\x13publish_mib_per_sec\x18\x01 \x01(\x01\x12\x1d\n\x15subscribe_mib_per_sec\x18\x02 \x01(\x01\"\x84\x01\n\x1fPubsubLiteTopicXPartitionConfig\x12\r\n\x05\x63ount\x18\x01 \x01(\x01\x12R\n\x08\x63\x61pacity\x18\x02 \x01(\x0b\x32@.oak9.tython.gcp.pubsub.PubsubLiteTopicXPartitionConfigXCapacity\"C\n!PubsubLiteTopicXReservationConfig\x12\x1e\n\x16throughput_reservation\x18\x01 \x01(\t\"N\n\x1fPubsubLiteTopicXRetentionConfig\x12\x1b\n\x13per_partition_bytes\x18\x01 \x01(\t\x12\x0e\n\x06period\x18\x02 \x01(\t\"J\n\x18PubsubLiteTopicXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xd4\x03\n\x0fPubsubLiteTopic\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07project\x18\x03 \x01(\t\x12\x0e\n\x06region\x18\x04 \x01(\t\x12\x0c\n\x04zone\x18\x05 \x01(\t\x12Q\n\x10partition_config\x18\x06 \x01(\x0b\x32\x37.oak9.tython.gcp.pubsub.PubsubLiteTopicXPartitionConfig\x12U\n\x12reservation_config\x18\x07 \x01(\x0b\x32\x39.oak9.tython.gcp.pubsub.PubsubLiteTopicXReservationConfig\x12Q\n\x10retention_config\x18\x08 \x01(\x0b\x32\x37.oak9.tython.gcp.pubsub.PubsubLiteTopicXRetentionConfig\x12\x42\n\x08timeouts\x18\t \x01(\x0b\x32\x30.oak9.tython.gcp.pubsub.PubsubLiteTopicXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"7\n\x15PubsubSchemaXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xd5\x01\n\x0cPubsubSchema\x12\x12\n\ndefinition\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04type\x18\x05 \x01(\t\x12?\n\x08timeouts\x18\x06 \x01(\x0b\x32-.oak9.tython.gcp.pubsub.PubsubSchemaXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"_\n#PubsubSubscriptionXDeadLetterPolicy\x12\x19\n\x11\x64\x65\x61\x64_letter_topic\x18\x01 \x01(\t\x12\x1d\n\x15max_delivery_attempts\x18\x02 \x01(\x01\"2\n#PubsubSubscriptionXExpirationPolicy\x12\x0b\n\x03ttl\x18\x01 \x01(\t\"Z\n\'PubsubSubscriptionXPushConfigXOidcToken\x12\x10\n\x08\x61udience\x18\x01 \x01(\t\x12\x1d\n\x15service_account_email\x18\x02 \x01(\t\"\x99\x02\n\x1dPubsubSubscriptionXPushConfig\x12Y\n\nattributes\x18\x01 \x03(\x0b\x32\x45.oak9.tython.gcp.pubsub.PubsubSubscriptionXPushConfig.AttributesEntry\x12\x15\n\rpush_endpoint\x18\x02 \x01(\t\x12S\n\noidc_token\x18\x03 \x01(\x0b\x32?.oak9.tython.gcp.pubsub.PubsubSubscriptionXPushConfigXOidcToken\x1a\x31\n\x0f\x41ttributesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"R\n\x1ePubsubSubscriptionXRetryPolicy\x12\x17\n\x0fmaximum_backoff\x18\x01 \x01(\t\x12\x17\n\x0fminimum_backoff\x18\x02 \x01(\t\"M\n\x1bPubsubSubscriptionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xc8\x06\n\x12PubsubSubscription\x12\x1c\n\x14\x61\x63k_deadline_seconds\x18\x01 \x01(\x01\x12$\n\x1c\x65nable_exactly_once_delivery\x18\x02 \x01(\x08\x12\x1f\n\x17\x65nable_message_ordering\x18\x03 \x01(\x08\x12\x0e\n\x06\x66ilter\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x46\n\x06labels\x18\x06 \x03(\x0b\x32\x36.oak9.tython.gcp.pubsub.PubsubSubscription.LabelsEntry\x12\"\n\x1amessage_retention_duration\x18\x07 \x01(\t\x12\x0c\n\x04name\x18\x08 \x01(\t\x12\x0f\n\x07project\x18\t \x01(\t\x12\x1d\n\x15retain_acked_messages\x18\n \x01(\x08\x12\r\n\x05topic\x18\x0b \x01(\t\x12W\n\x12\x64\x65\x61\x64_letter_policy\x18\x0c \x01(\x0b\x32;.oak9.tython.gcp.pubsub.PubsubSubscriptionXDeadLetterPolicy\x12V\n\x11\x65xpiration_policy\x18\r \x01(\x0b\x32;.oak9.tython.gcp.pubsub.PubsubSubscriptionXExpirationPolicy\x12J\n\x0bpush_config\x18\x0e \x01(\x0b\x32\x35.oak9.tython.gcp.pubsub.PubsubSubscriptionXPushConfig\x12L\n\x0cretry_policy\x18\x0f \x01(\x0b\x32\x36.oak9.tython.gcp.pubsub.PubsubSubscriptionXRetryPolicy\x12\x45\n\x08timeouts\x18\x10 \x01(\x0b\x32\x33.oak9.tython.gcp.pubsub.PubsubSubscriptionXTimeouts\x12\x37\n\rresource_info\x18\x11 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"`\n&PubsubSubscriptionIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x8a\x02\n\x1cPubsubSubscriptionIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x14\n\x0csubscription\x18\x06 \x01(\t\x12Q\n\tcondition\x18\x07 \x01(\x0b\x32>.oak9.tython.gcp.pubsub.PubsubSubscriptionIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"_\n%PubsubSubscriptionIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\x87\x02\n\x1bPubsubSubscriptionIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\x14\n\x0csubscription\x18\x06 \x01(\t\x12P\n\tcondition\x18\x07 \x01(\x0b\x32=.oak9.tython.gcp.pubsub.PubsubSubscriptionIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xac\x01\n\x1bPubsubSubscriptionIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x14\n\x0csubscription\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"G\n PubsubTopicXMessageStoragePolicy\x12#\n\x1b\x61llowed_persistence_regions\x18\x01 \x03(\t\">\n\x1aPubsubTopicXSchemaSettings\x12\x10\n\x08\x65ncoding\x18\x01 \x01(\t\x12\x0e\n\x06schema\x18\x02 \x01(\t\"F\n\x14PubsubTopicXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x82\x04\n\x0bPubsubTopic\x12\n\n\x02id\x18\x01 \x01(\t\x12\x14\n\x0ckms_key_name\x18\x02 \x01(\t\x12?\n\x06labels\x18\x03 \x03(\x0b\x32/.oak9.tython.gcp.pubsub.PubsubTopic.LabelsEntry\x12\"\n\x1amessage_retention_duration\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12X\n\x16message_storage_policy\x18\x07 \x01(\x0b\x32\x38.oak9.tython.gcp.pubsub.PubsubTopicXMessageStoragePolicy\x12K\n\x0fschema_settings\x18\x08 \x01(\x0b\x32\x32.oak9.tython.gcp.pubsub.PubsubTopicXSchemaSettings\x12>\n\x08timeouts\x18\t \x01(\x0b\x32,.oak9.tython.gcp.pubsub.PubsubTopicXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"Y\n\x1fPubsubTopicIamBindingXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf5\x01\n\x15PubsubTopicIamBinding\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0f\n\x07members\x18\x03 \x03(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\r\n\x05topic\x18\x06 \x01(\t\x12J\n\tcondition\x18\x07 \x01(\x0b\x32\x37.oak9.tython.gcp.pubsub.PubsubTopicIamBindingXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"X\n\x1ePubsubTopicIamMemberXCondition\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x12\n\nexpression\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\"\xf2\x01\n\x14PubsubTopicIamMember\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0e\n\x06member\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\x0c\n\x04role\x18\x05 \x01(\t\x12\r\n\x05topic\x18\x06 \x01(\t\x12I\n\tcondition\x18\x07 \x01(\x0b\x32\x36.oak9.tython.gcp.pubsub.PubsubTopicIamMemberXCondition\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9e\x01\n\x14PubsubTopicIamPolicy\x12\x0c\n\x04\x65tag\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x13\n\x0bpolicy_data\x18\x03 \x01(\t\x12\x0f\n\x07project\x18\x04 \x01(\t\x12\r\n\x05topic\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_pubsub_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PUBSUBSUBSCRIPTIONXPUSHCONFIG_ATTRIBUTESENTRY._options = None
  _PUBSUBSUBSCRIPTIONXPUSHCONFIG_ATTRIBUTESENTRY._serialized_options = b'8\001'
  _PUBSUBSUBSCRIPTION_LABELSENTRY._options = None
  _PUBSUBSUBSCRIPTION_LABELSENTRY._serialized_options = b'8\001'
  _PUBSUBTOPIC_LABELSENTRY._options = None
  _PUBSUBTOPIC_LABELSENTRY._serialized_options = b'8\001'
  _PUBSUBLITERESERVATIONXTIMEOUTS._serialized_start=69
  _PUBSUBLITERESERVATIONXTIMEOUTS._serialized_end=149
  _PUBSUBLITERESERVATION._serialized_start=152
  _PUBSUBLITERESERVATION._serialized_end=394
  _PUBSUBLITESUBSCRIPTIONXDELIVERYCONFIG._serialized_start=396
  _PUBSUBLITESUBSCRIPTIONXDELIVERYCONFIG._serialized_end=465
  _PUBSUBLITESUBSCRIPTIONXTIMEOUTS._serialized_start=467
  _PUBSUBLITESUBSCRIPTIONXTIMEOUTS._serialized_end=548
  _PUBSUBLITESUBSCRIPTION._serialized_start=551
  _PUBSUBLITESUBSCRIPTION._serialized_end=883
  _PUBSUBLITETOPICXPARTITIONCONFIGXCAPACITY._serialized_start=885
  _PUBSUBLITETOPICXPARTITIONCONFIGXCAPACITY._serialized_end=987
  _PUBSUBLITETOPICXPARTITIONCONFIG._serialized_start=990
  _PUBSUBLITETOPICXPARTITIONCONFIG._serialized_end=1122
  _PUBSUBLITETOPICXRESERVATIONCONFIG._serialized_start=1124
  _PUBSUBLITETOPICXRESERVATIONCONFIG._serialized_end=1191
  _PUBSUBLITETOPICXRETENTIONCONFIG._serialized_start=1193
  _PUBSUBLITETOPICXRETENTIONCONFIG._serialized_end=1271
  _PUBSUBLITETOPICXTIMEOUTS._serialized_start=1273
  _PUBSUBLITETOPICXTIMEOUTS._serialized_end=1347
  _PUBSUBLITETOPIC._serialized_start=1350
  _PUBSUBLITETOPIC._serialized_end=1818
  _PUBSUBSCHEMAXTIMEOUTS._serialized_start=1820
  _PUBSUBSCHEMAXTIMEOUTS._serialized_end=1875
  _PUBSUBSCHEMA._serialized_start=1878
  _PUBSUBSCHEMA._serialized_end=2091
  _PUBSUBSUBSCRIPTIONXDEADLETTERPOLICY._serialized_start=2093
  _PUBSUBSUBSCRIPTIONXDEADLETTERPOLICY._serialized_end=2188
  _PUBSUBSUBSCRIPTIONXEXPIRATIONPOLICY._serialized_start=2190
  _PUBSUBSUBSCRIPTIONXEXPIRATIONPOLICY._serialized_end=2240
  _PUBSUBSUBSCRIPTIONXPUSHCONFIGXOIDCTOKEN._serialized_start=2242
  _PUBSUBSUBSCRIPTIONXPUSHCONFIGXOIDCTOKEN._serialized_end=2332
  _PUBSUBSUBSCRIPTIONXPUSHCONFIG._serialized_start=2335
  _PUBSUBSUBSCRIPTIONXPUSHCONFIG._serialized_end=2616
  _PUBSUBSUBSCRIPTIONXPUSHCONFIG_ATTRIBUTESENTRY._serialized_start=2567
  _PUBSUBSUBSCRIPTIONXPUSHCONFIG_ATTRIBUTESENTRY._serialized_end=2616
  _PUBSUBSUBSCRIPTIONXRETRYPOLICY._serialized_start=2618
  _PUBSUBSUBSCRIPTIONXRETRYPOLICY._serialized_end=2700
  _PUBSUBSUBSCRIPTIONXTIMEOUTS._serialized_start=2702
  _PUBSUBSUBSCRIPTIONXTIMEOUTS._serialized_end=2779
  _PUBSUBSUBSCRIPTION._serialized_start=2782
  _PUBSUBSUBSCRIPTION._serialized_end=3622
  _PUBSUBSUBSCRIPTION_LABELSENTRY._serialized_start=3577
  _PUBSUBSUBSCRIPTION_LABELSENTRY._serialized_end=3622
  _PUBSUBSUBSCRIPTIONIAMBINDINGXCONDITION._serialized_start=3624
  _PUBSUBSUBSCRIPTIONIAMBINDINGXCONDITION._serialized_end=3720
  _PUBSUBSUBSCRIPTIONIAMBINDING._serialized_start=3723
  _PUBSUBSUBSCRIPTIONIAMBINDING._serialized_end=3989
  _PUBSUBSUBSCRIPTIONIAMMEMBERXCONDITION._serialized_start=3991
  _PUBSUBSUBSCRIPTIONIAMMEMBERXCONDITION._serialized_end=4086
  _PUBSUBSUBSCRIPTIONIAMMEMBER._serialized_start=4089
  _PUBSUBSUBSCRIPTIONIAMMEMBER._serialized_end=4352
  _PUBSUBSUBSCRIPTIONIAMPOLICY._serialized_start=4355
  _PUBSUBSUBSCRIPTIONIAMPOLICY._serialized_end=4527
  _PUBSUBTOPICXMESSAGESTORAGEPOLICY._serialized_start=4529
  _PUBSUBTOPICXMESSAGESTORAGEPOLICY._serialized_end=4600
  _PUBSUBTOPICXSCHEMASETTINGS._serialized_start=4602
  _PUBSUBTOPICXSCHEMASETTINGS._serialized_end=4664
  _PUBSUBTOPICXTIMEOUTS._serialized_start=4666
  _PUBSUBTOPICXTIMEOUTS._serialized_end=4736
  _PUBSUBTOPIC._serialized_start=4739
  _PUBSUBTOPIC._serialized_end=5253
  _PUBSUBTOPIC_LABELSENTRY._serialized_start=3577
  _PUBSUBTOPIC_LABELSENTRY._serialized_end=3622
  _PUBSUBTOPICIAMBINDINGXCONDITION._serialized_start=5255
  _PUBSUBTOPICIAMBINDINGXCONDITION._serialized_end=5344
  _PUBSUBTOPICIAMBINDING._serialized_start=5347
  _PUBSUBTOPICIAMBINDING._serialized_end=5592
  _PUBSUBTOPICIAMMEMBERXCONDITION._serialized_start=5594
  _PUBSUBTOPICIAMMEMBERXCONDITION._serialized_end=5682
  _PUBSUBTOPICIAMMEMBER._serialized_start=5685
  _PUBSUBTOPICIAMMEMBER._serialized_end=5927
  _PUBSUBTOPICIAMPOLICY._serialized_start=5930
  _PUBSUBTOPICIAMPOLICY._serialized_end=6088
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg import runtime_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_runtime__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x12-oak9.tython.k8s.apimachinery.pkg.apis.meta.v1\x1a\x13shared/shared.proto\x1a;kubernetes/kubernetes_io.k8s.apimachinery.pkg.runtime.proto\"\xa5\x03\n\x08\x41PIGroup\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x62\n\x11preferred_version\x18\x04 \x01(\x0b\x32G.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.GroupVersionForDiscovery\x12p\n\x1eserver_address_by_client_cidrs\x18\x05 \x03(\x0b\x32H.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ServerAddressByClientCIDR\x12Y\n\x08versions\x18\x06 \x03(\x0b\x32G.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.GroupVersionForDiscovery\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb3\x01\n\x0c\x41PIGroupList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12G\n\x06groups\x18\x02 \x03(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.APIGroup\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x83\x02\n\x0b\x41PIResource\x12\x12\n\ncategories\x18\x01 \x03(\t\x12\r\n\x05group\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x12\n\nnamespaced\x18\x05 \x01(\x08\x12\x13\n\x0bshort_names\x18\x06 \x03(\t\x12\x15\n\rsingular_name\x18\x07 \x01(\t\x12\x1c\n\x14storage_version_hash\x18\x08 \x01(\t\x12\r\n\x05verbs\x18\t \x03(\t\x12\x0f\n\x07version\x18\n \x01(\t\x12\x37\n\rresource_info\x18\x0b \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd3\x01\n\x0f\x41PIResourceList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x15\n\rgroup_version\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12M\n\tresources\x18\x04 \x03(\x0b\x32:.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.APIResource\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xed\x01\n\x0b\x41PIVersions\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12p\n\x1eserver_address_by_client_cidrs\x18\x03 \x03(\x0b\x32H.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ServerAddressByClientCIDR\x12\x10\n\x08versions\x18\x04 \x03(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf3\x01\n\tCondition\x12Q\n\x14last_transition_time\x18\x01 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x1b\n\x13observed_generation\x18\x03 \x01(\x05\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa6\x02\n\rDeleteOptions\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0f\n\x07\x64ry_run\x18\x02 \x03(\t\x12\x1c\n\x14grace_period_seconds\x18\x03 \x01(\x05\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12\x19\n\x11orphan_dependents\x18\x05 \x01(\x08\x12S\n\rpreconditions\x18\x06 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Preconditions\x12\x1a\n\x12propagation_policy\x18\x07 \x01(\t\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"C\n\x08\x46ieldsV1\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"{\n\x18GroupVersionForDiscovery\x12\x15\n\rgroup_version\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc5\x02\n\rLabelSelector\x12\x62\n\x11match_expressions\x18\x01 \x03(\x0b\x32G.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelectorRequirement\x12\x63\n\x0cmatch_labels\x18\x02 \x03(\x0b\x32M.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector.MatchLabelsEntry\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10MatchLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x82\x01\n\x18LabelSelectorRequirement\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x10\n\x08operator\x18\x02 \x01(\t\x12\x0e\n\x06values\x18\x03 \x03(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa0\x01\n\x08ListMeta\x12\x10\n\x08\x63ontinue\x18\x01 \x01(\t\x12\x1c\n\x14remaining_item_count\x18\x02 \x01(\x05\x12\x18\n\x10resource_version\x18\x03 \x01(\t\x12\x11\n\tself_link\x18\x04 \x01(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbf\x02\n\x12ManagedFieldsEntry\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x13\n\x0b\x66ields_type\x18\x02 \x01(\t\x12J\n\tfields_v1\x18\x03 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.FieldsV1\x12\x0f\n\x07manager\x18\x04 \x01(\t\x12\x11\n\toperation\x18\x05 \x01(\t\x12\x13\n\x0bsubresource\x18\x06 \x01(\t\x12\x41\n\x04time\x18\x07 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"D\n\tMicroTime\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf7\x06\n\nObjectMeta\x12_\n\x0b\x61nnotations\x18\x01 \x03(\x0b\x32J.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta.AnnotationsEntry\x12O\n\x12\x63reation_timestamp\x18\x02 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12%\n\x1d\x64\x65letion_grace_period_seconds\x18\x03 \x01(\x05\x12O\n\x12\x64\x65letion_timestamp\x18\x04 \x01(\x0b\x32\x33.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Time\x12\x12\n\nfinalizers\x18\x05 \x03(\t\x12\x15\n\rgenerate_name\x18\x06 \x01(\t\x12\x12\n\ngeneration\x18\x07 \x01(\x05\x12U\n\x06labels\x18\x08 \x03(\x0b\x32\x45.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta.LabelsEntry\x12Y\n\x0emanaged_fields\x18\t \x03(\x0b\x32\x41.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ManagedFieldsEntry\x12\x0c\n\x04name\x18\n \x01(\t\x12\x11\n\tnamespace\x18\x0b \x01(\t\x12W\n\x10owner_references\x18\x0c \x03(\x0b\x32=.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.OwnerReference\x12\x18\n\x10resource_version\x18\r \x01(\t\x12\x11\n\tself_link\x18\x0e \x01(\t\x12\x0b\n\x03uid\x18\x0f \x01(\t\x12\x37\n\rresource_info\x18\x10 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x1a\x32\n\x10\x41nnotationsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb9\x01\n\x0eOwnerReference\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x1c\n\x14\x62lock_owner_deletion\x18\x02 \x01(\x08\x12\x12\n\ncontroller\x18\x03 \x01(\x08\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0b\n\x03uid\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"@\n\x05Patch\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"o\n\rPreconditions\x12\x18\n\x10resource_version\x18\x01 \x01(\t\x12\x0b\n\x03uid\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x81\x01\n\x19ServerAddressByClientCIDR\x12\x13\n\x0b\x63lient_cidr\x18\x01 \x01(\t\x12\x16\n\x0eserver_address\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xbd\x02\n\x06Status\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12M\n\x07\x64\x65tails\x18\x03 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.StatusDetails\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12\x0f\n\x07message\x18\x05 \x01(\t\x12I\n\x08metadata\x18\x06 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x0e\n\x06reason\x18\x07 \x01(\t\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"v\n\x0bStatusCause\x12\r\n\x05\x66ield\x18\x01 \x01(\t\x12\x0f\n\x07message\x18\x02 \x01(\t\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe9\x01\n\rStatusDetails\x12J\n\x06\x63\x61uses\x18\x01 \x03(\x0b\x32:.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.StatusCause\x12\r\n\x05group\x18\x02 \x01(\t\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x1b\n\x13retry_after_seconds\x18\x05 \x01(\x05\x12\x0b\n\x03uid\x18\x06 \x01(\t\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"?\n\x04Time\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9b\x01\n\nWatchEvent\x12\x46\n\x06object\x18\x01 \x01(\x0b\x32\x36.oak9.tython.k8s.apimachinery.pkg.runtime.RawExtension\x12\x0c\n\x04type\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _LABELSELECTOR_MATCHLABELSENTRY._options = None
  _LABELSELECTOR_MATCHLABELSENTRY._serialized_options = b'8\001'
  _OBJECTMETA_ANNOTATIONSENTRY._options = None
  _OBJECTMETA_ANNOTATIONSENTRY._serialized_options = b'8\001'
  _OBJECTMETA_LABELSENTRY._options = None
  _OBJECTMETA_LABELSENTRY._serialized_options = b'8\001'
  _APIGROUP._serialized_start=198
  _APIGROUP._serialized_end=619
  _APIGROUPLIST._serialized_start=622
  _APIGROUPLIST._serialized_end=801
  _APIRESOURCE._serialized_start=804
  _APIRESOURCE._serialized_end=1063
  _APIRESOURCELIST._serialized_start=1066
  _APIRESOURCELIST._serialized_end=1277
  _APIVERSIONS._serialized_start=1280
  _APIVERSIONS._serialized_end=1517
  _CONDITION._serialized_start=1520
  _CONDITION._serialized_end=1763
  _DELETEOPTIONS._serialized_start=1766
  _DELETEOPTIONS._serialized_end=2060
  _FIELDSV1._serialized_start=2062
  _FIELDSV1._serialized_end=2129
  _GROUPVERSIONFORDISCOVERY._serialized_start=2131
  _GROUPVERSIONFORDISCOVERY._serialized_end=2254
  _LABELSELECTOR._serialized_start=2257
  _LABELSELECTOR._serialized_end=2582
  _LABELSELECTOR_MATCHLABELSENTRY._serialized_start=2532
  _LABELSELECTOR_MATCHLABELSENTRY._serialized_end=2582
  _LABELSELECTORREQUIREMENT._serialized_start=2585
  _LABELSELECTORREQUIREMENT._serialized_end=2715
  _LISTMETA._serialized_start=2718
  _LISTMETA._serialized_end=2878
  _MANAGEDFIELDSENTRY._serialized_start=2881
  _MANAGEDFIELDSENTRY._serialized_end=3200
  _MICROTIME._serialized_start=3202
  _MICROTIME._serialized_end=3270
  _OBJECTMETA._serialized_start=3273
  _OBJECTMETA._serialized_end=4160
  _OBJECTMETA_ANNOTATIONSENTRY._serialized_start=4063
  _OBJECTMETA_ANNOTATIONSENTRY._serialized_end=4113
  _OBJECTMETA_LABELSENTRY._serialized_start=4115
  _OBJECTMETA_LABELSENTRY._serialized_end=4160
  _OWNERREFERENCE._serialized_start=4163
  _OWNERREFERENCE._serialized_end=4348
  _PATCH._serialized_start=4350
  _PATCH._serialized_end=4414
  _PRECONDITIONS._serialized_start=4416
  _PRECONDITIONS._serialized_end=4527
  _SERVERADDRESSBYCLIENTCIDR._serialized_start=4530
  _SERVERADDRESSBYCLIENTCIDR._serialized_end=4659
  _STATUS._serialized_start=4662
  _STATUS._serialized_end=4979
  _STATUSCAUSE._serialized_start=4981
  _STATUSCAUSE._serialized_end=5099
  _STATUSDETAILS._serialized_start=5102
  _STATUSDETAILS._serialized_end=5335
  _TIME._serialized_start=5337
  _TIME._serialized_end=5400
  _WATCHEVENT._serialized_start=5403
  _WATCHEVENT._serialized_end=5558
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_AAD(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DOMAIN_SERVICES_FIELD_NUMBER: builtins.int
    @property
    def domain_services(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DomainServices]: ...
    def __init__(
        self,
        *,
        domain_services: collections.abc.Iterable[global___DomainServices] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain_services", b"domain_services"]) -> None: ...

global___Microsoft_AAD = Microsoft_AAD

@typing_extensions.final
class DomainServicesOuContainer(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ACCOUNT_NAME_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PASSWORD_FIELD_NUMBER: builtins.int
    SPN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    account_name: builtins.str
    name: builtins.str
    password: builtins.str
    spn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        account_name: builtins.str = ...,
        name: builtins.str = ...,
        password: builtins.str = ...,
        spn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["account_name", b"account_name", "name", b"name", "password", b"password", "resource_info", b"resource_info", "spn", b"spn"]) -> None: ...

global___DomainServicesOuContainer = DomainServicesOuContainer

@typing_extensions.final
class DomainServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    DOMAIN_CONFIGURATION_TYPE_FIELD_NUMBER: builtins.int
    DOMAIN_NAME_FIELD_NUMBER: builtins.int
    DOMAIN_SECURITY_SETTINGS_FIELD_NUMBER: builtins.int
    FILTERED_SYNC_FIELD_NUMBER: builtins.int
    LDAPS_SETTINGS_FIELD_NUMBER: builtins.int
    NOTIFICATION_SETTINGS_FIELD_NUMBER: builtins.int
    REPLICA_SETS_FIELD_NUMBER: builtins.int
    RESOURCE_FOREST_SETTINGS_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    DOMAIN_SERVICES_OU_CONTAINER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    location: builtins.str
    name: builtins.str
    domain_configuration_type: builtins.str
    domain_name: builtins.str
    @property
    def domain_security_settings(self) -> global___DomainSecuritySettings: ...
    filtered_sync: builtins.str
    @property
    def ldaps_settings(self) -> global___LdapsSettings: ...
    @property
    def notification_settings(self) -> global___NotificationSettings: ...
    @property
    def replica_sets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplicaSet]: ...
    @property
    def resource_forest_settings(self) -> global___ResourceForestSettings: ...
    sku: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def domain_services_ou_container(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___DomainServicesOuContainer]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        domain_configuration_type: builtins.str = ...,
        domain_name: builtins.str = ...,
        domain_security_settings: global___DomainSecuritySettings | None = ...,
        filtered_sync: builtins.str = ...,
        ldaps_settings: global___LdapsSettings | None = ...,
        notification_settings: global___NotificationSettings | None = ...,
        replica_sets: collections.abc.Iterable[global___ReplicaSet] | None = ...,
        resource_forest_settings: global___ResourceForestSettings | None = ...,
        sku: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        domain_services_ou_container: collections.abc.Iterable[global___DomainServicesOuContainer] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["domain_security_settings", b"domain_security_settings", "ldaps_settings", b"ldaps_settings", "notification_settings", b"notification_settings", "resource_forest_settings", b"resource_forest_settings", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["domain_configuration_type", b"domain_configuration_type", "domain_name", b"domain_name", "domain_security_settings", b"domain_security_settings", "domain_services_ou_container", b"domain_services_ou_container", "etag", b"etag", "filtered_sync", b"filtered_sync", "ldaps_settings", b"ldaps_settings", "location", b"location", "name", b"name", "notification_settings", b"notification_settings", "replica_sets", b"replica_sets", "resource_forest_settings", b"resource_forest_settings", "resource_info", b"resource_info", "sku", b"sku", "tags", b"tags"]) -> None: ...

global___DomainServices = DomainServices

@typing_extensions.final
class ResourceForestSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_FOREST_FIELD_NUMBER: builtins.int
    SETTINGS_FIELD_NUMBER: builtins.int
    resource_forest: builtins.str
    @property
    def settings(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ForestTrust]: ...
    def __init__(
        self,
        *,
        resource_forest: builtins.str = ...,
        settings: collections.abc.Iterable[global___ForestTrust] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_forest", b"resource_forest", "settings", b"settings"]) -> None: ...

global___ResourceForestSettings = ResourceForestSettings

@typing_extensions.final
class ForestTrust(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FRIENDLY_NAME_FIELD_NUMBER: builtins.int
    REMOTE_DNS_IPS_FIELD_NUMBER: builtins.int
    TRUST_DIRECTION_FIELD_NUMBER: builtins.int
    TRUSTED_DOMAIN_FQDN_FIELD_NUMBER: builtins.int
    TRUST_PASSWORD_FIELD_NUMBER: builtins.int
    friendly_name: builtins.str
    remote_dns_ips: builtins.str
    trust_direction: builtins.str
    trusted_domain_fqdn: builtins.str
    trust_password: builtins.str
    def __init__(
        self,
        *,
        friendly_name: builtins.str = ...,
        remote_dns_ips: builtins.str = ...,
        trust_direction: builtins.str = ...,
        trusted_domain_fqdn: builtins.str = ...,
        trust_password: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["friendly_name", b"friendly_name", "remote_dns_ips", b"remote_dns_ips", "trust_direction", b"trust_direction", "trust_password", b"trust_password", "trusted_domain_fqdn", b"trusted_domain_fqdn"]) -> None: ...

global___ForestTrust = ForestTrust

@typing_extensions.final
class ReplicaSet(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LOCATION_FIELD_NUMBER: builtins.int
    SUBNET_ID_FIELD_NUMBER: builtins.int
    location: builtins.str
    subnet_id: builtins.str
    def __init__(
        self,
        *,
        location: builtins.str = ...,
        subnet_id: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "subnet_id", b"subnet_id"]) -> None: ...

global___ReplicaSet = ReplicaSet

@typing_extensions.final
class NotificationSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDITIONAL_RECIPIENTS_FIELD_NUMBER: builtins.int
    NOTIFY_DC_ADMINS_FIELD_NUMBER: builtins.int
    NOTIFY_GLOBAL_ADMINS_FIELD_NUMBER: builtins.int
    @property
    def additional_recipients(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    notify_dc_admins: builtins.str
    notify_global_admins: builtins.str
    def __init__(
        self,
        *,
        additional_recipients: collections.abc.Iterable[builtins.str] | None = ...,
        notify_dc_admins: builtins.str = ...,
        notify_global_admins: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_recipients", b"additional_recipients", "notify_dc_admins", b"notify_dc_admins", "notify_global_admins", b"notify_global_admins"]) -> None: ...

global___NotificationSettings = NotificationSettings

@typing_extensions.final
class LdapsSettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    EXTERNAL_ACCESS_FIELD_NUMBER: builtins.int
    LDAPS_FIELD_NUMBER: builtins.int
    PFX_CERTIFICATE_FIELD_NUMBER: builtins.int
    PFX_CERTIFICATE_PASSWORD_FIELD_NUMBER: builtins.int
    external_access: builtins.str
    ldaps: builtins.str
    pfx_certificate: builtins.str
    pfx_certificate_password: builtins.str
    def __init__(
        self,
        *,
        external_access: builtins.str = ...,
        ldaps: builtins.str = ...,
        pfx_certificate: builtins.str = ...,
        pfx_certificate_password: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["external_access", b"external_access", "ldaps", b"ldaps", "pfx_certificate", b"pfx_certificate", "pfx_certificate_password", b"pfx_certificate_password"]) -> None: ...

global___LdapsSettings = LdapsSettings

@typing_extensions.final
class DomainSecuritySettings(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KERBEROS_ARMORING_FIELD_NUMBER: builtins.int
    KERBEROS_RC4_ENCRYPTION_FIELD_NUMBER: builtins.int
    NTLM_V1_FIELD_NUMBER: builtins.int
    SYNC_KERBEROS_PASSWORDS_FIELD_NUMBER: builtins.int
    SYNC_NTLM_PASSWORDS_FIELD_NUMBER: builtins.int
    SYNC_ON_PREM_PASSWORDS_FIELD_NUMBER: builtins.int
    TLS_V1_FIELD_NUMBER: builtins.int
    kerberos_armoring: builtins.str
    kerberos_rc4_encryption: builtins.str
    ntlm_v1: builtins.str
    sync_kerberos_passwords: builtins.str
    sync_ntlm_passwords: builtins.str
    sync_on_prem_passwords: builtins.str
    tls_v1: builtins.str
    def __init__(
        self,
        *,
        kerberos_armoring: builtins.str = ...,
        kerberos_rc4_encryption: builtins.str = ...,
        ntlm_v1: builtins.str = ...,
        sync_kerberos_passwords: builtins.str = ...,
        sync_ntlm_passwords: builtins.str = ...,
        sync_on_prem_passwords: builtins.str = ...,
        tls_v1: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["kerberos_armoring", b"kerberos_armoring", "kerberos_rc4_encryption", b"kerberos_rc4_encryption", "ntlm_v1", b"ntlm_v1", "sync_kerberos_passwords", b"sync_kerberos_passwords", "sync_ntlm_passwords", b"sync_ntlm_passwords", "sync_on_prem_passwords", b"sync_on_prem_passwords", "tls_v1", b"tls_v1"]) -> None: ...

global___DomainSecuritySettings = DomainSecuritySettings
